@@ -1,6 +1,6 @@
 ;;; phps-mode-indent.el -- Indentation for phps-mode -*- lexical-binding: t -*-
 
-;; Copyright (C) 2018-2022  Free Software Foundation, Inc.
+;; Copyright (C) 2018-2023  Free Software Foundation, Inc.
 
 
 
@@ -40,21 +40,24 @@
         nil))))
 
 (defun phps-mode-indent--string-starts-with-regexp (string regexp &optional match-index)
-  "If STRING start with REGEXP, return it, otherwise nil.  With optional MATCH-INDEX."
+  "If STRING start with REGEXP, return it,
+otherwise nil.  With optional MATCH-INDEX."
   (phps-mode-indent--string-match-regexp
    string
    (concat "^" regexp)
    match-index))
 
 (defun phps-mode-indent--string-ends-with-regexp (string regexp &optional match-index)
-  "If STRING end with REGEXP, return it, otherwise nil.  With optional MATCH-INDEX."
+  "If STRING end with REGEXP, return it,
+otherwise nil.  With optional MATCH-INDEX."
   (phps-mode-indent--string-match-regexp
    string
    (concat regexp "$")
    match-index))
 
 (defun phps-mode-indent--string-match-regexp (string regexp &optional match-index)
-  "If STRING match REGEXP, return it, otherwise nil.  With optional MATCH-INDEX."
+  "If STRING match REGEXP, return it, otherwise nil.
+With optional MATCH-INDEX."
   (unless match-index
     (setq match-index 0))
   (if
@@ -216,7 +219,8 @@
       html-bracket-level)))
 
 (defun phps-mode-indent--get-previous-reference-index-line ()
-  "Get previous index line as reference, if any exist.  A index line is a previous element line inside current bracket scope."
+  "Get previous index line as reference, if any exist.
+A index line is a previous element line inside current bracket scope."
   (let ((reference-line))
     (save-excursion
       (end-of-line)
@@ -228,7 +232,7 @@
             (and
              not-found-bracket-start
              (search-backward-regexp
-              "\\([][{}(),]\\|=>\\)"
+              "\\([][{}(),:]\\|=>\\)"
               nil
               t))
           (let ((match (match-string-no-properties 0)))
@@ -285,10 +289,12 @@
                     (line-beginning-position)
                     (line-end-position))))))
 
-             ;; The first occurrence of a =>
+             ;; The first occurrence of a => or :
              ;; is a significant marker of
              ;; a starting bracket row
-             ((string= "=>" match)
+             ((or
+               (string= "=>" match)
+               (string= ":" match))
               (when (= parenthesis-level 0)
                 (setq
                  reference-line
@@ -304,7 +310,8 @@
 
 (defun phps-mode-indent--get-previous-start-of-bracket-line
     (&optional from-end-of-line)
-  "Get previous start of bracket line as reference, if any exist.  Optionally start FROM-END-OF-LINE."
+  "Get previous start of bracket line as reference, if any exist.
+Optionally start FROM-END-OF-LINE."
   (let ((reference-line))
     (save-excursion
       (if from-end-of-line
@@ -537,7 +544,7 @@
               ")[\ t]*:[\t ]*$"
               match)
              (string-match-p
-              "[^:]:[\t ]*$"
+              "\\(case\\|default\\).*:[\t ]*$"
               match)) ;; Like case '50':
             (setq
              not-found
@@ -895,6 +902,20 @@
                  new-indentation
                  (+ new-indentation tab-width)))
 
+               ;; LINE AFTER FUNCTION CALL WITH NAMED ARGUMENT
+               ;; arg1:
+               ;;     $something
+               ((and
+                 (string-match-p
+                  "^[\t ]*[a-zA-Z0-9_]+[\t ]*:[\t ]*$"
+                  previous-line-string))
+                (setq
+                 match-type
+                 'line-after-function-call-with-named-argument)
+                (setq
+                 new-indentation
+                 (+ new-indentation tab-width)))
+
                ;; LINE AFTER INLINE OR ALTERNATIVE ELSE / ELSEIF CONTROL STRUCTURE
                ;; else
                ;;     echo 'Something';
@@ -1126,7 +1147,8 @@
                ;; default:
                ((and
                  (not previous-line-ends-with-opening-bracket)
-                 (not (string-match-p ":[\t ]*$" previous-line-string))
+                 (not (string-match-p ")[\t ]*:[\t ]*$" previous-line-string))
+                 (not (string-match-p "^[\t ]*case[\t ]*" previous-line-string))
                  (or
                   (string-match-p
                    "^[\t ]*case[\t ]+.*\\(;\\|:\\)[\t ]*$"
@@ -1214,6 +1236,13 @@
                ;;     [
                ;;         2,
                ;;         3,
+               ;; or
+               ;; myFunction(
+               ;;     arg1:
+               ;;         $var1,
+               ;;     arg2:
+               ;;         $var2,
+               ;; );
                ((string-match-p
                  ",[\t ]*\\(\\?>[\t\n ]*\\)?$"
                  previous-line-string)
@@ -1258,6 +1287,37 @@
                    new-indentation
                    (- new-indentation tab-width))))
 
+               ;; LINE AFTER CASE DEFINITION
+               ;; case true:
+               ;;     echo 'here';
+               ;; or
+               ;; case true;
+               ;;     echo 'here';
+               ;; or
+               ;; default:
+               ;;     echo 'here';
+               ;; or
+               ;; default;
+               ;;     echo 'here';
+               ((and
+                 (not
+                  (string-match-p
+                   "^[\t ]*\\(case[\t ]+\\|default\\)"
+                   current-line-string))
+                 (or
+                  (string-match-p
+                   "^[\t ]*case[\t ]+.*\\(;\\|:\\)[\t ]*$"
+                   previous-line-string)
+                  (string-match-p
+                   "^[\t ]*default.*\\(;\\|:\\)[\t ]*$"
+                   previous-line-string)))
+                (setq
+                 match-type
+                 'line-after-case-definition)
+                (setq
+                 new-indentation
+                 (+ new-indentation tab-width)))
+
                ;; LINE AFTER LINE THATS ENDS WITH SEMICOLON
                ;; $var .=
                ;;     'hello';
@@ -1312,6 +1372,9 @@
                ;; LINE AFTER ALTERNATIVE CASE DEFINITION
                ;; switch ($array):
                ;;     case 'Something';
+               ;; or
+               ;; switch ($array):
+               ;;     case 'Something':
                ((and
                  (string-match-p
                   "^[\t ]*\\(case.+\\|default\\)\\(;\\|:\\)[\t ]*$"
@@ -1700,37 +1763,6 @@
                  new-indentation
                  (+ new-indentation tab-width)))
 
-               ;; LINE AFTER CASE DEFINITION
-               ;; case true:
-               ;;     echo 'here';
-               ;; or
-               ;; case true;
-               ;;     echo 'here';
-               ;; or
-               ;; default:
-               ;;     echo 'here';
-               ;; or
-               ;; default;
-               ;;     echo 'here';
-               ((and
-                 (not
-                  (string-match-p
-                   "^[\t ]*\\(case[\t ]+\\|default\\)"
-                   current-line-string))
-                 (or
-                  (string-match-p
-                   "^[\t ]*case[\t ]+.*\\(;\\|:\\)[\t ]*$"
-                   previous-line-string)
-                  (string-match-p
-                   "^[\t ]*default.*\\(;\\|:\\)[\t ]*$"
-                   previous-line-string)))
-                (setq
-                 match-type
-                 'line-after-case-definition)
-                (setq
-                 new-indentation
-                 (+ new-indentation tab-width)))
-
                )
 
               (phps-mode-debug-message
